Skip to contents

Supports tar_force(). This is really an internal function and not meant to be called by users directly.

Usage

tar_force_change(condition)

Arguments

condition

Logical, whether to run the downstream target in tar_force().

Value

A hash that changes when the downstream target is supposed to run.