Internal function needed for tar_knit().
Users should not invoke it directly.
Arguments
- path
Character string, file path to the
knitrsource file. Must have length 1.- working_directory
Optional character string, path to the working directory to temporarily set when running the report. The default is
NULL, which runs the report from the current working directory at the time the pipeline is run. This default is recommended in the vast majority of cases. To use anything other thanNULL, you must manually set the value of thestoreargument relative to the working directory in all calls totar_read()andtar_load()in the report. Otherwise, these functions will not know where to find the data.- args
A named list of arguments to
knitr::knit().- deps
An unnamed list of target dependencies of the
knitrreport, automatically created bytar_knit().