Run a dynamic batch of a tar_map2() target.
Arguments
- command
Command to run.
- values
Data frame of named arguments produced by
command1thatcommand2dynamically maps over. Different from thevaluesargument oftar_map2().- columns
tidyselect expression to select columns of
valuesto append to the result.- rep_workers
Positive integer of length 1, number of local R processes to use to run reps within batches in parallel. If 1, then reps are run sequentially within each batch. If greater than 1, then reps within batch are run in parallel using a PSOCK cluster.