Get Source Files From Quarto Inspect
Source:R/tar_quarto_files.R
tar_quarto_files_get_source_files.RdCollects all files from the
fileInformation field that are used in the current report.
Arguments
- file_information
The
fileInformationelement of the list returned byquarto::quarto_inspect().
Details
fileInformation contains a list of files. Each file entry contains
two data frames. The first, includeMap, contains a source column (files
that include other files, e.g. the main report file) and a target column
(files that get included by the source files). The codeCells data frame
contains all code cells from the files represented in includeMap.