Render a batch of parameterized R Markdown reports inside a tar_render_rep() target.
Source: R/tar_render_rep_raw.R
tar_render_rep_run.RdInternal function needed for tar_render().
Users should not invoke it directly.
Arguments
- path
Path to the R Markdown source file.
- args
A named list of arguments to
rmarkdown::render().- deps
An unnamed list of target dependencies of the R Markdown report, automatically created by
tar_render_rep().- rep_workers
Positive integer of length 1, number of local R processes to use to run reps within batches in parallel. If 1, then reps are run sequentially within each batch. If greater than 1, then reps within batch are run in parallel using a PSOCK cluster.