Skip to contents

Internal function needed for tar_render(). Users should not invoke it directly.

Usage

tar_render_run(path, args, deps)

Arguments

path

Path to the R Markdown source file.

args

A named list of arguments to rmarkdown::render().

deps

An unnamed list of target dependencies of the R Markdown report, automatically created by tar_render().

Value

Character vector with the path to the R Markdown source file and the relative path to the output. These paths depend on the input source file path and have no defaults.